optional

package
v1.0.6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 21, 2025 License: MIT Imports: 1 Imported by: 0

Documentation

Overview

Package optional provides utility functions for implementing functional options pattern across the Paystack Go SDK.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Bool

func Bool(b bool) *bool

Bool returns a pointer to the given bool value

func Float64

func Float64(f float64) *float64

Float64 returns a pointer to the given float64 value

func Int

func Int(i int) *int

Int returns a pointer to the given int value

func String

func String(s string) *string

String returns a pointer to the given string value

func Time

func Time(t time.Time) *time.Time

Time returns a pointer to the given time.Time value

func Uint64

func Uint64(u uint64) *uint64

Uint64 returns a pointer to the given uint64 value

Types

This section is empty.

Jump to